@@ -47,19 +47,25 @@ where
 	/// $1$
 	const ONE: Self;
 
-	/// Lanewise saturating add.
+	/// Saturating add.
+	#[must_use]
 	fn saturating_add(self, other: Self) -> Self;
-	/// Lanewise saturating subtract.
+	/// Saturating subtract.
+	#[must_use]
 	fn saturating_sub(self, other: Self) -> Self;
 
-	/// Lanewise absolute subtract.
+	/// Absolute subtract.
 	///
 	/// Equals `self.saturating_sub(other) | other.saturating_sub(self)`.
+	#[must_use]
+	#[inline]
 	fn abs_sub(self, other: Self) -> Self {
 		self.saturating_sub(other) | other.saturating_sub(self)
 	}
 
 	/// Constructs a SIMD vector by setting all lanes to the given value.
+	#[must_use]
+	#[inline]
 	fn splat<const LANES: usize>(self) -> Self::Simd<LANES>
 	where
 		LaneCount<LANES>: SupportedLaneCount,
