@@ -151,6 +151,7 @@ where
 	///
 	/// Note that this function is distinct from `as` casting, which attempts to preserve the
 	/// *numeric* value, and not the bitwise value.
+	#[must_use]
 	fn from_bits(bits: Self::Bits) -> Self;
 	/// Raw transmutation to `u64`.
 	///
@@ -162,79 +163,102 @@ where
 	///
 	/// Note that this function is distinct from `as` casting, which attempts to preserve the
 	/// *numeric* value, and not the bitwise value.
+	#[must_use]
 	fn to_bits(self) -> Self::Bits;
 
 	/// Returns `true` for each lane if it has a positive sign, including `+0.0`, NaNs with positive
 	/// sign bit and positive infinity.
+	#[must_use]
 	fn is_sign_positive(self) -> bool;
 	/// Returns `true` for each lane if it has a negative sign, including `-0.0`, NaNs with negative
 	/// sign bit and negative infinity.
+	#[must_use]
 	fn is_sign_negative(self) -> bool;
 	/// Returns `true` for each lane if its value is NaN.
+	#[must_use]
 	fn is_nan(self) -> bool;
 	/// Returns `true` for each lane if its value is positive infinity or negative infinity.
+	#[must_use]
 	fn is_infinite(self) -> bool;
 	/// Returns `true` for each lane if its value is neither infinite nor NaN.
+	#[must_use]
 	fn is_finite(self) -> bool;
 	/// Returns `true` for each lane if its value is subnormal.
+	#[must_use]
 	fn is_subnormal(self) -> bool;
 	/// Returns `true` for each lane if its value is neither neither zero, infinite, subnormal, or
 	/// NaN.
+	#[must_use]
 	fn is_normal(self) -> bool;
 	/// Returns the floating point category of the number.
 	///
 	/// If only one property is going to be tested, it is generally faster to use the specific
 	/// predicate instead.
+	#[must_use]
 	fn classify(self) -> FpCategory;
 
 	/// Returns the largest integer less than or equal to a number.
+	#[must_use]
 	fn floor(self) -> Self;
 	/// Returns the smallest integer greater than or equal to a number.
+	#[must_use]
 	fn ceil(self) -> Self;
 	/// Returns the nearest integer to a number. Round half-way cases away from `0.0`.
+	#[must_use]
 	fn round(self) -> Self;
 	/// Returns the integer part of a number.
+	#[must_use]
 	fn trunc(self) -> Self;
 	/// Returns the fractional part of a number.
+	#[must_use]
 	fn fract(self) -> Self;
 
 	/// Computes the absolute value of `self`.
 	///
 	/// Returns [`Self::NAN`] if the number is NaN.
+	#[must_use]
 	fn abs(self) -> Self;
 	/// Returns a number that represents the sign of `self`.
 	///
 	///  * Returns `1.0` if the number is positive, `+0.0` or [`Self::INFINITY`].
 	///  * Returns `-1.0` if the number is negative, `-0.0` or [`Self::NEG_INFINITY`].
 	///  * Returns [`Self::NAN`] if the number is NaN.
+	#[must_use]
 	fn signum(self) -> Self;
 	/// Returns a number composed of the magnitude of `self` and the sign of `sign`.
 	///
 	/// Equal to `self` if the sign of `self` and `sign` are the same, otherwise equal to `-self`.
 	///
 	/// If `self` is NaN, then NaN with the sign of `sign` is returned.
+	#[must_use]
 	fn copysign(self, sign: Self) -> Self;
 	/// Returns the minimum of each lane.
 	///
 	/// If one of the values is NaN, then the other value is returned.
+	#[must_use]
 	fn min(self, other: Self) -> Self;
 	/// Returns the maximum of each lane.
 	///
 	/// If one of the values is NaN, then the other value is returned.
+	#[must_use]
 	fn max(self, other: Self) -> Self;
 	/// Restrict each lane to a certain interval unless it is NaN.
 	///
 	/// For each lane in `self`, returns the corresponding lane in `max` if the lane is greater than
 	/// `max`, and the corresponding lane in `min` if the lane is less than `min`. Otherwise,
 	/// returns the lane in `self`.
+	#[must_use]
 	fn clamp(self, min: Self, max: Self) -> Self;
 
 	/// Takes the reciprocal (inverse) of a number, `1 / self`.
+	#[must_use]
 	fn recip(self) -> Self;
 
 	/// Converts degrees to radians.
+	#[must_use]
 	fn to_radians(self) -> Self;
 	/// Converts radians to degrees.
+	#[must_use]
 	fn to_degrees(self) -> Self;
 
 	/// Fused multiply-add. Computes `(self * a) + b` with only one rounding error, yielding a more
@@ -243,12 +267,14 @@ where
 	/// Using `mul_add` *may* be more performant than an unfused multiply-add if the target
 	/// architecture has a dedicated `fma` CPU instruction. However, this is not always true, and
 	/// will be heavily dependant on designing algorithms with specific target hardware in mind.
+	#[must_use]
 	fn mul_add(self, a: Self, b: Self) -> Self;
 
 	/// Calculates Euclidean division, the matching method for [`Self::rem_euclid()`].
 	///
 	/// This computes the integer `n` such that `self = n * rhs + self.rem_euclid(rhs)`. In other
 	/// words, the result is `self / rhs` rounded to the integer `n` such that `self >= n * rhs`.
+	#[must_use]
 	fn div_euclid(self, rhs: Self) -> Self;
 	/// Calculates the least non-negative remainder of `self (mod rhs)`.
 	///
@@ -258,20 +284,27 @@ where
 	/// `self < 0.0`. This result is not an element of the function's codomain, but it is the
 	/// closest floating point number in the real numbers and thus fulfills the property
 	/// `self == self.div_euclid(rhs) * rhs + self.rem_euclid(rhs)` approximatively.
+	#[must_use]
 	fn rem_euclid(self, rhs: Self) -> Self;
 
 	/// Raises a number to a floating-point power.
+	#[must_use]
 	fn powf(self, n: Self) -> Self;
 	/// Returns $e^x$.
+	#[must_use]
 	fn exp(self) -> Self;
 	/// Returns $e^x - 1$ in a way that is accurate even if the number is close to zero.
+	#[must_use]
 	fn exp_m1(self) -> Self;
 	/// Returns $2^x$.
+	#[must_use]
 	fn exp2(self) -> Self;
 	/// Returns the natural logarithm of the number.
+	#[must_use]
 	fn ln(self) -> Self;
 	/// Returns the natural logarithm of the number plus one more accurately than if the operations
 	/// were performed separately.
+	#[must_use]
 	fn ln_1p(self) -> Self;
 	/// Returns the logarithm of the number with respect to an arbitrary base.
 	///
@@ -279,56 +312,74 @@ where
 	///
 	///   * [`Self::log2()`] can produce more accurate results for base $2$, and
 	///   * [`Self::log10()`] can produce more accurate results for base $10$.
+	#[must_use]
 	fn log(self, base: Self) -> Self;
 	/// Returns the base $2$ logarithm of the number.
+	#[must_use]
 	fn log2(self) -> Self;
 	/// Returns the base $10$ logarithm of the number.
+	#[must_use]
 	fn log10(self) -> Self;
 
 	/// Returns the square root of a number.
 	///
 	/// Returns NaN if `self` is a negative number.
+	#[must_use]
 	fn sqrt(self) -> Self;
 	/// Returns the cube root of a number.
+	#[must_use]
 	fn cbrt(self) -> Self;
 
 	/// Calculates the length of the hypotenuse of a right-angle triangle given legs of length
 	/// `self` and `other`.
+	#[must_use]
 	fn hypot(self, other: Self) -> Self;
 
 	/// Computes the sine of a number in radians.
+	#[must_use]
 	fn sin(self) -> Self;
 	/// Computes the hyperbolic sine of a number in radians.
+	#[must_use]
 	fn sinh(self) -> Self;
 	/// Computes the cosine of a number in radians.
+	#[must_use]
 	fn cos(self) -> Self;
 	/// Computes the hyperbolic cosine of a number in radians.
+	#[must_use]
 	fn cosh(self) -> Self;
 	/// Simultaneously computes the sine and cosine of `self`.
 	///
 	/// Returns `(self.sin(), self.cos())`.
+	#[must_use]
 	fn sin_cos(self) -> (Self, Self);
 	/// Computes the tangent of a number in radians.
+	#[must_use]
 	fn tan(self) -> Self;
 	/// Computes the arcsine of a number.
 	///
 	/// Return value is in radians in the range $[-{\pi \over 2}, {\pi \over 2}]$ or NaN if the
 	/// number is outside the range $[-1, 1]$.
+	#[must_use]
 	fn asin(self) -> Self;
 	/// Inverse hyperbolic sine function.
+	#[must_use]
 	fn asinh(self) -> Self;
 	/// Computes the arccosine of a number.
 	///
 	/// Return value is in radians in the range $[0, \pi]$ or NaN if the number is outside the range
 	/// $[-1, 1]$.
+	#[must_use]
 	fn acos(self) -> Self;
 	/// Inverse hyperbolic cosine function.
+	#[must_use]
 	fn acosh(self) -> Self;
 	/// Computes the arctangent of a number.
 	///
 	/// Return value is in radians in the range $[-{\pi \over 2}, {\pi \over 2}]$.
+	#[must_use]
 	fn atan(self) -> Self;
 	/// Inverse hyperbolic tangent function.
+	#[must_use]
 	fn atanh(self) -> Self;
 	/// Computes the four quadrant arctangent of `self` as $y$ and `other` as $x$ in radians.
 	///
@@ -340,6 +391,7 @@ where
 	///   \arctan({y \over x}) - \pi \in (-{\pi \over 2}, -{\pi \over 2}) & \text{if } y \lt 0
 	/// \end{cases}
 	/// $$
+	#[must_use]
 	fn atan2(self, other: Self) -> Self;
 
 	/// Linear interpolation between `start` and `end`.
@@ -365,6 +417,7 @@ where
 	///   `start == end`. (consistency)
 	///
 	/// [finite]: `Self::is_finite()`
+	#[must_use]
 	fn lerp(self, start: Self, end: Self) -> Self;
 
 	/// Returns an ordering between self and other values.
@@ -389,9 +442,11 @@ where
 	/// Note that this function does not always agree with the [`PartialOrd`] and [`PartialEq`]
 	/// implementations of floating-point type. In particular, they regard negative and positive
 	/// zero as equal, while [`Self::total_cmp()`] does not.
+	#[must_use]
 	fn total_cmp(&self, other: &Self) -> Ordering;
 
 	/// Tests for approximate equality wrt `epsilon` or `ulp`, "or" in the sense of `||`.
+	#[must_use]
 	fn approx_eq(self, other: Self, epsilon: Self, ulp: Self::Bits) -> bool {
 		Real::abs(self - other) <= epsilon
 			|| !self.is_nan()
@@ -400,11 +455,15 @@ where
 				&& self.to_bits().abs_sub(other.to_bits()) <= ulp
 	}
 	/// Tests for approximate inequality wrt `epsilon` and `ulp`, "and" in the sense of `&&`.
+	#[must_use]
+	#[inline]
 	fn approx_ne(self, other: Self, epsilon: Self, ulp: Self::Bits) -> bool {
 		!self.approx_eq(other, epsilon, ulp)
 	}
 
 	/// Constructs a SIMD vector by setting all lanes to the given value.
+	#[must_use]
+	#[inline]
 	fn splat<const LANES: usize>(self) -> Self::Simd<LANES>
 	where
 		LaneCount<LANES>: SupportedLaneCount,
